### Description

A metaphor is a figure of speech in which someone speaks of one thing as if it were a different thing because he wants people to think about how those two things are alike.

For example, someone might say, “The girl I love is a red rose.”

A girl and a rose are very different things, but the speaker considers that they are alike in some way. The hearer’s task is to understand in what way they are alike.

### The Parts of a Metaphor

The example above shows us that a metaphor has three parts. In this metaphor, the speaker is talking about “the girl I love.” This is the **Topic**. The speaker wants the hearer to think about what is similar between her and “a red rose.” The red rose is the **Image** to which he compares the girl. Most probably, he wants the hearer to consider that they are both beautiful. This is the **Idea** that the girl and the rose both share, and so we may also call it the **Point of Comparison**.

Every metaphor has three parts:

* The **Topic**, the item being immediately discussed by the writer/speaker.

* The **Image**, the physical item (object, event, action, etc.) which the speaker uses to describe the topic.

* The **Idea**, the abstract concept or quality that the physical **Image** brings to the mind of the hearer when he thinks of how the **Image** and the **Topic** are similar. Often, the **Idea** of a metaphor is not explicitly stated in the Bible, but it is only implied from the context. The hearer or reader usually needs to think of the **Idea** himself.


Using these terms, we can say that a metaphor is a figure of speech that uses a physical **Image** to apply an abstract **Idea** to the speaker’s **Topic**.

Usually, a writer or speaker uses a metaphor in order to express something about a **Topic**, with at least one **Point of Comparison** (**Idea**) between the **Topic** and the **Image**. Often in metaphors, the **Topic** and the **Image** are explicitly stated, but the **Idea** is only implied. The writer/speaker often uses a metaphor in order to invite the readers/listeners to think about the similarity between the **Topic** and the **Image** and to figure out for themselves the **Idea** that is being communicated.

Speakers often use metaphors in order to strengthen their message, to make their language more vivid, to express their feelings better, to say something that is hard to say in any other way, or to help people remember their message.

Sometimes speakers use metaphors that are very common in their language. However, sometimes speakers use metaphors that are uncommon, and even some metaphors that are unique. When a metaphor has become very common in a language, often it becomes a “passive” metaphor, in contrast to uncommon metaphors, which we describe as being “active.” Passive metaphors and active metaphors each present a different kind of translation problem, which we will discuss below.

### Passive Metaphors

A passive metaphor is a metaphor that has been used so much in the language that its speakers no longer regard it as one concept standing for another. Linguists often call these “dead metaphors.” Passive metaphors are extremely common. Examples in English include the terms “table **leg**,” “family **tree**,” “book **leaf**” (meaning a page in a book), or the word “crane” (meaning a large machine for lifting heavy loads). English speakers simply think of these words as having more than one meaning. Examples of passive metaphors in Biblical Hebrew include using the word “hand” to represent “power,” using the word “face” to represent “presence,” and speaking of emotions or moral qualities as if they were “clothing.”

#### Patterned Pairs of Concepts Acting as Metaphors

Many ways of metaphorical speaking depend on pairs of concepts, where one underlying concept frequently stands for a different underlying concept. For example, in English, the direction “up” (the Image) often represents the concepts of “more” or “better” (the Idea). Because of this pair of underlying concepts, we can make sentences such as “The price of gasoline is going **up**,” “A **highly** intelligent man,” and also the opposite kind of idea: “The temperature is going **down**,” and “I am feeling very **low**.”

Patterned pairs of concepts are constantly used for metaphorical purposes in the world’s languages because they serve as convenient ways to organize thought. In general, people like to speak of abstract qualities (such as power, presence, emotions, and moral qualities) as if they were body parts, or as if they were objects that could be seen or held, or as if they were events that could be watched as they happened.

When these metaphors are used in normal ways, it is rare that the speaker and audience regard them as figurative speech. Examples of metaphors in English that go unrecognized are:

* “Turn the heat **up**.” More is spoken of as up.
* “Let us **go ahead** with our debate.” Doing what was planned is spoken of as walking or advancing.
* “You **defend** your theory well.” Argument is spoken of as war.
* “A **flow** of words.” Words are spoken of as liquids.

English speakers do not view these as metaphorical expressions or figures of speech, so it would be wrong to translate them into other languages in a way that would lead people to pay special attention to them as figurative speech. For a description of important patterns of this kind of metaphor in biblical languages, please see [Biblical Imagery – Common Patterns](../bita-part1/01.md) and the pages it will direct you to.

When translating something that is a passive metaphor into another language, do not treat it as a metaphor. Instead, just use the best expression for that thing or concept in the target language.

### Active Metaphors

These are metaphors that people recognize as one concept standing for another concept, or one thing for another thing. Metaphors make people think about how the one thing is like the other thing, because in most ways the two things are very different. People also easily recognize these metaphors as giving strength and unusual qualities to the message. For this reason, people pay attention to these metaphors. For example,

> But for you who fear my name, the sun of righteousness will rise with healing in its wings. (Malachi 4:2a ULT)

Here, God speaks about his salvation as if it were the sun rising in order to shine its rays on the people whom he loves. He also speaks of the sun’s rays as if they were wings. Also, he speaks of these wings as if they were bringing medicine that would heal his people. Here is another example:

> And he said to them, “Go and tell that fox …” (Luke 13:32a ULT)

Here, “that fox” refers to King Herod. The people listening to Jesus certainly understood that Jesus was intending for them to apply certain characteristics of a fox to Herod. They probably understood that Jesus intended to communicate that Herod was evil, either in a cunning way or as someone who was destructive, murderous, or who took things that did not belong to him, or all of these.

Active metaphors require the translator’s special care to make a correct translation. To do so, you need to understand the parts of a metaphor and how they work together to produce meaning.

> Jesus said to them, “I am the bread of life; he who comes to me will not be hungry, and he who believes in me will never be thirsty.” (John 6:35 ULT)

In this metaphor, Jesus called himself the bread of life. The **Topic** is “I” (meaning Jesus himself) and the **Image** is “bread.” Bread was the primary food that people ate in that place and time. The similarity between bread and Jesus is that people need both to live. Just as people need to eat food in order to have physical life, people need to trust in Jesus in order to have eternal life. The **Idea** of the metaphor is “life.” In this case, Jesus stated the central Idea of the metaphor, but often the Idea is only implied.

### Purposes of Metaphor

* One purpose of metaphor is to teach people about something that they do not know (the **Topic**) by showing that it is like something that they already do know (the **Image**).
* Another purpose is to emphasize that something (the **Topic**) has a particular quality (the **Idea**) or to show that it has that quality in an extreme way.
* Another purpose is to lead people to feel the same way about the **Topic** as they would feel about the **Image**.

### Reasons This Is a Translation Issue

* People may not recognize that something is a metaphor. In other words, they may mistake a metaphor for a literal statement, and thus, misunderstand it.
* People may not be familiar with the thing that is used as an image, and so, not be able to understand the metaphor.
* If the topic is not stated, people may not know what the topic is.
* People may not know the points of comparison that the speaker wants them to understand. If they fail to think of these points of comparison, they will not understand the metaphor.
* People may think that they understand the metaphor, but they do not. This can happen when they apply points of comparison from their own culture, rather than from the biblical culture.

#### Translation Principles

* Make the meaning of a metaphor as clear to the target audience as it was to the original audience.
* Do not make the meaning of a metaphor more clear to the target audience than you think it was to the original audience.

### Examples From the Bible

> Listen to this word, **you cows of Bashan**, (Amos 4:1q ULT)

In this metaphor Amos speaks to the upper-class women of Samaria (“you,” the Topic) as if they were cows (the Image). Amos does not say what similarity(s) he intends between these women and cows. He wants the reader to think of them, and he fully expects that readers from his culture will easily do so. From the context, we can see that he means that the women are like cows in that they are fat and interested only in feeding themselves. If we were to apply similarities from a different culture, such as that cows are sacred and should be worshiped, we would get the wrong meaning from this verse.

NOTE: Amos does not actually mean that the women are cows. He speaks to them as human beings.

> Yet, Yahweh, you are our father; **we are the clay**. **You are our potter**; and we all are the work of your hand. (Isaiah 64:8 ULT)

The example above has two related metaphors. The Topic(s) are “we” and “you,” and the Image(s) are “clay” and “potter.” The similarity between a potter and God is the fact that both make what they wish out of their material. The potter makes what he wishes out of the clay, and God makes what he wishes out of his people. The Idea being expressed by the comparison between the potter’s clay and “us” is that **neither the clay nor God’s people have a right to complain about what they are becoming**.

> Jesus said to them, “Take heed and beware of **the yeast of the Pharisees and Sadducees**.” The disciples reasoned among themselves and said, “It is because we did not take bread.” (Matthew 16:6-7 ULT)

Jesus used a metaphor here, but his disciples did not realize it. When he said “yeast,” they thought he was talking about bread, but “yeast” was the Image in his metaphor, and the Topic was the teaching of the Pharisees and Sadducees. Since the disciples (the original audience) did not understand what Jesus meant, it would not be good to state clearly here what Jesus meant.

### Translation Strategies

If people would understand the metaphor in the same way that the original readers would have understood it, go ahead and use it. Be sure to test the translation to make sure that people do understand it in the right way.

If people do not or would not understand it, here are some other strategies.

(1) If the metaphor is a common expression in the source language or expresses a patterned pair of concepts in a biblical language (that is, it is a passive metaphor), then express the **Idea** in the simplest way preferred by your language.  
(2) If the metaphor seems to be an active metaphor, you can translate it literally **if you think that the target language also uses this metaphor in the same way to mean the same thing as in the Bible**. If you do this, be sure to test it to make sure that the language community understands it correctly.  
(3) If the target audience does not realize that it is a metaphor, then change the metaphor to a simile. Some languages do this by adding words such as “like” or “as.” See [Simile](../figs-simile/01.md).  
(4) If the target audience would not know the **Image**, see [Translate Unknowns](../translate-unknown/01.md) for ideas on how to translate that image.  
(5) If the target audience would not use that **Image** for that meaning, use an image from your own culture instead. Be sure that it is an image that could have been possible in Bible times.  
(6) If the target audience would not know what the **Topic** is, then state the topic clearly. (However, do not do this if the original audience did not know what the Topic was.)  
(7) If the target audience would not know the intended similarity (the **Idea**) between the topic and the image, then state it clearly.  
(8) If none of these strategies is satisfactory, then simply state the **Idea** plainly without using a metaphor.

### Examples of Translation Strategies Applied

(1) If the metaphor is a common expression in the source language or expresses a patterned pair of concepts in a biblical language (that is, a passive metaphor), then express the Idea in the simplest way preferred by your language.

> Then, see, one of the leaders of the synagogue, named Jairus, came, and when he saw him, **fell at his feet**. (Mark 5:22 ULT)
>
> > Then one of the leaders of the synagogue, named Jairus, came, and when he saw him, **immediately bowed down in front of him**.

(2) If the metaphor seems to be an active metaphor, you can translate it literally **if you think that the target language also uses this metaphor in the same way to mean the same thing as in the Bible**. If you do this, be sure to test it to make sure that the language community understands it correctly.

> But Jesus said to them, “He wrote this commandment to you because of your **hardness of heart.**” (Mark 10:5 ULT)
>
> > It was because of your **hard hearts** that he wrote you this law.

We made no change to this one, but it must be tested to make sure that the target audience correctly understands this metaphor.

(3) If the target audience does not realize that it is a metaphor, then change the metaphor to a simile. Some languages do this by adding words such as “like” or “as.”

> Yet, Yahweh, you are our father; we **are the clay.** You **are our potter**; and we all are the work of your hand. (Isaiah 64:8 ULT)
>
> > And yet, Yahweh, you are our father; we are **like** clay. You are **like** a potter; and we all are the work of your hand.

(4) If the target audience would not know the **Image**, see [Translate Unknowns](../translate-unknown/01.md) for ideas on how to translate that image.

> Saul, Saul, why do you persecute me? It is hard for you **to kick against a goad**. (Acts 26:14b ULT)
>
> > Saul, Saul, why do you persecute me? It is hard for you to **kick against a pointed stick**.

(5) If the target audience would not use that **Image** for that meaning, use an image from your own culture instead. Be sure that it is an image that could have been possible in Bible times.

> Yet, Yahweh, you are our father; we are the **clay**. You are our **potter**; and we all are the work of your hand. (Isaiah 64:8 ULT)
>
> > “And yet, Yahweh, you are our father; we are the **wood**. You are our **carver**; and we all are the work of your hand.”
> > “And yet, Yahweh, you are our father; we are the **string**. You are the **weaver**; and we all are the work of your hand.”

(6) If the target audience would not know what the **Topic** is, then state the topic clearly. (However, do not do this if the original audience did not know what the topic was.)

> Yahweh lives; may **my rock** be praised. May the God of my salvation be exalted. (Psalm 18:46 ULT)
>
> > Yahweh lives; **He is my rock**. May he be praised. May the God of my salvation be exalted.

(7) If the target audience would not know the intended similarity between the Topic and the Image, then state it clearly.

> Yahweh lives; may **my rock** be praised. May the God of my salvation be exalted. (Psalm 18:46 ULT)
>
> > Yahweh lives; may he be praised because he is the rock **under which I can hide from my enemies**. May the God of my salvation be exalted.
>
> Saul, Saul, why do you persecute me? It is hard for you **to kick against a goad**. (Acts 26:14 ULT)
>
> > Saul, Saul, why do you persecute me? You **fight against me and hurt yourself like an ox that kicks against its owner’s pointed stick**.

(8) If none of these strategies are satisfactory, then simply state the idea plainly without using a metaphor.

> I will make you to become **fishers of men**. (Mark 1:17b ULT)
>
> > I will make you to become **people who gather men**.
> > Now you gather fish. I will make you **gather people**.

To learn more about specific metaphors, see [Biblical Imagery – Common Patterns](../bita-part1/01.md).
