## Time Relationship

Some connectors establish time relationships between two phrases, clauses, sentences, or chunks of text.

### Background Clause

#### Description

A background clause is one that describes something that is ongoing. Then, in the same sentence, another clause indicates an event that begins to happen during that time. These events are also simultaneous events, but they have the further relationship of background event and main event because the event that is already happening serves as the background for the other event, the one that is in focus. The background event simply provides the time frame or other context for the main event or events.

#### Reason This Is a Translation Issue

Languages indicate a shift in time in different ways. You (the translator) need to understand how these shifts in time are indicated in the original languages in order to communicate them clearly in your own language. Background clauses often indicate a time that began long before the event that is in focus. Translators need to understand how both the source language and the target language communicate background events. Some English words that indicate background events are “now,” “when,” “while,” and “during.” Those words can also indicate simultaneous events. To tell the difference, ask yourself if all of the events seem to be equal in importance and started at about the same time. If so, they are probably simultaneous events. But if an event(s) is ongoing and another event(s) just started, then the ongoing event(s) is probably background to the other event(s). Some common phrases that indicate background events are “in those days” and “at that time.”

#### Examples From OBS and the Bible

> **When** Solomon was old, he also worshiped their gods. (OBS Story 18 Frame 3)

Solomon began to worship foreign gods at a time when he was old. Being old is the background event. Worshiping other gods is the main event.

> And his parents went **every year** to Jerusalem to the Feast of the Passover. And when he was 12 years old, they went up according to the custom of the feast. (Luke 2:41-42 ULT)

The first event—going to Jerusalem—is ongoing and started long ago. We know this because of the words “every year.” Going to Jerusalem is the background event. Then an event begins that started during the time “when he was twelve years old.” So the main event is the specific time Jesus and his family traveled to Jerualem for the Passover festival **when he was twelve years old.**

> And it came about that, **while** they were there, the days were fulfilled for her to give birth. (Luke 2:6 ULT)

Being in Bethlehem is the background event. The birth of the baby is the main event.

> And in the fifteenth year of the reign of Tiberius Caesar—**while** Pontius Pilate was governor of Judea, and Herod was tetrarch of Galilee, and his brother Philip was tetrarch of the region of Ituraea and Trachonitis, and Lysanias was tetrarch of Abilene, **during** the high priesthood of Annas and Caiaphas—the word of God came to John, the son of Zechariah, in the wilderness. (Luke 3:1-2 ULT)

This example begins with five background clauses (marked by commas), signalled as background by the words “while” and “during.” Then the main event happens: “the word of God came to John.”

#### Translation Strategies

If the way that the Background Clauses are marked is also clear in your language, then translate the Background Clauses as they are.

(1) If the connecting word does not make it clear that what follows is a Background Clause, use a connecting word that communicates this more clearly.  
(2) If your language marks Background Clauses in a different way than using connecting words (such as by using different verb forms), then use that way.

#### Examples of Translation Strategies Applied

> And in the fifteenth year of the reign of Tiberius Caesar—**while** Pontius Pilate was governor of Judea, and Herod was tetrarch of Galilee, and his brother Philip was tetrarch of the region of Ituraea and Trachonitis, and Lysanias was tetrarch of Abilene, **during** the high priesthood of Annas and Caiaphas—the word of God came to John, the son of Zechariah, in the wilderness. (Luke 3:1-2 ULT)

(1) If the connecting word does not make it clear that what follows is a background clause, use a connecting word that communicates this more clearly.

> **It happened during the time that** Pontius Pilate was governor of Judea, **and during the time that** Herod was tetrarch of Galilee, **and during the time that** his brother Philip was tetrarch of the region of Ituraea and Trachonitis, **and during the time that** Lysanias was tetrarch of Abilene, **and also during the time that** Annas and Caiaphas were high priests—**that** the word of God came to John son of Zechariah in the wilderness.

(2) If your language marks background clauses in a different way than using connecting words, such as with different verb forms, then use that way.

> Pontius Pilate **was governing** Judea, and Herod **was ruling over** Galilee, and his brother Philip **was ruling over** the region of Ituraea and Trachonitis, and Lysanias **was ruling over** Abilene, and Annas and Caiaphas **were being** high priests—the word of God **came** to John son of Zechariah in the wilderness.

#### Example of Differences in Time Relationship Connecting Words:

                          |                                              |
| ------------------------ | -------------------------------------------- |
Background setting         |Yahweh’s word was rare **in those days**;|
|Background repeated       | there was no frequent prophetic vision. |
|Introduction of main event|**At that time**, **when** Eli |
|Background                        |**whose** eyesight had begun to grow dim so that he could             not see well,|
|Simultaneous background      |was lying down in his own bed.
|Simultaneous background      | The lamp of God **had not yet** gone out, |
|Simultaneous background      |**and** Samuel was lying down to sleep in the temple of Yahweh,|
| Simultaneous background     | where the ark of God was. |
|Main event                           |**Yahweh called to Samuel**, |
|Sequential event                   |who said, “Here I am.” (1 Sam 3:1-4 ULT) |

In the above example, the first two lines talk about a condition that was going on for a long time. This is the general, long-term background. We know this from the phrase “in those days.” After the introduction of the main event (“At that time,”), there are several lines of simultaneous background. The first one is introduced by “when,” and then three more follow, with the last connected by “and.” The background clause introduced by “where” explains a little more about the background clause before it. Then the main event happens, followed by more events. Translators will need to think about the best way to show these relationships in their language.
