### Definitions

These are definitions of words that we use to talk about how people make the sounds that form into words, and also definitions of words that refer to the parts of words.

#### Consonant

These are the sounds that people make when the air flow from their lungs is interrupted or limited by the position of the tongue, teeth or lips. The majority of letters in the alphabet are consonant letters. Most consonant letters have only one sound.

#### Vowel

These sounds are made by the mouth when the breath flows out through the mouth without being blocked by the teeth, tongue, or lips. (In English, vowels are a, e, i, o, u and sometimes y.)

#### Syllable (syl-ab-al)

A part of a word that has only one vowel sound, with or without surrounding consonants. Some words have only one syllable.

#### Affix

Something that is added to a word that changes its meaning. This could be at the beginning, or the end, or in the body of a word.

#### Root

The most basic part of a word. The root is what is left when all the affixes are removed.

#### Morpheme

A word or a part of a word that has a meaning and that contains no smaller part that has a meaning. (For example, “syllable” has 3 syllables, but only 1 morpheme, while “syllables” has 3 syllables and two morphemes (syl-lab-le**s**). (The final “s” is a morpheme that means “plural.”)

### How Syllables Make Words

Every language has sounds which combine to form syllables. An affix of a word or the root of a word may have a single syllable, or it may have a number of syllables. Sounds combine to make syllables which also join together to make morphemes. Morphemes work together to make meaningful words.
It is important to understand the way syllables are formed in your language and how those syllables influence one another so that spelling rules can be written and people can more easily learn to read your language.

Vowel sounds are the basic part of syllables. English has only five vowel symbols, “a, e, i, o, u.” But English has up to 11 vowel sounds that are written with vowel combinations and many other ways. The sounds of individual English vowels can be found in words such as, “beat, bit, bait, bet, bat, but, body, bought, boat, book, boot.”

![](https://cdn.door43.org/ta/jpg/aticulation.jpg)

#### The Vowels of English

| Position in the Mouth | Front | Mid | Back |
| -------- | -------- | -------- | -------- |
| ROUNDING | (unrounded) | (unrounded) | (rounded)
| Tongue High | I “beat” |    | U “boot” |
| Tongue Mid-High | I “bit” |    | U “book” |
| Tongue Middle | E “bait” | U “but” | O “boat” |
| Tongue Mid-Low |    | E “bet” | O “bought” |
| Tongue Low | A “bat” |    | A “body” |

(Each of these vowels has its own symbol in the International Phonetic Alphabet.)

The vowel sounds form the middle of each syllable, and the consonant sounds come before and after the vowels.

**Articulation** is the description of how air comes through the mouth or nose to produce the sounds that we can recognize as speech.

**Points of articulation** are those places along the throat or mouth where air is constricted or its flow is stopped. Common points of articulation include the lips, the teeth, the dental (alveolar) ridge, the palate (hard roof of the mouth), the velum (soft roof of the mouth), uvula, and the vocal cords (or glottis).

**Articulators** are the moving parts of the mouth, particularly the parts of the tongue that slow the flow of air. The parts of the tongue that can do this include the tongue root, the back, the blade, and the tip. The lips can also slow the air flow through the mouth without the use of the tongue. Sounds made with the lips include consonants such as “b,” “v,” and “m.”

The **manner of articulation** describes how the airflow is slowed. It can come to a complete stop (as with “p” or “b,” which are called stop consonants or stops), have heavy friction (like “f” or “v,” called fricatives), or be only slightly restricted (like “w” or “y,” called semi-vowels, because they are almost as free as vowels.)

**Voicing** shows whether or not the vocal chords are vibrating when the air passes through them. Most vowels, such as “a, e, i, u, o” are voiced sounds. Consonants can be voiced (+v), like “b,d,g,v,” or voiceless (-v) such as “p,t,k,f.” These are made at the same point of articulation and with the same articulators as the voiced consonants first mentioned. The only difference between “b,d,g,v” and “p,t,k,f” is voicing (+v and –v).

#### The Consonants of English

| Points of Articulation | Lips | Teeth | Ridge | Palate | Velum | Uvula | Glottis |
| -------- | -------- | -------- | -------- | -------- | -------- | -------- | -------- |
| VOICING | -v / +v | -v / +v | -v / +v | -v / +v | -v / +v | -v / +v | -v / +v |
| ARTICULATOR (manner) |    |    |    |    |    |    |    |
| Lips (stop) | “p” / “b” |    |    |    |    |    |    |
| Lip (fricative) |    | “f” / “v” |    |    |    |    |    |
| Tongue Tip (stop) |    |    | “t” / “d” |    |    |    |    |
| Tongue Tip (liquid) |    |    | – / “l” | – / “r” |    |    |    |
| Tongue Blade (fricative) |    |    | “s” / “z”   | “sh” / “zh” |    |    |    |
| Tongue Back (stop) |    |    |    |    | “k” / “g” |    |    |
| Tongue Root (semi-vowel) | – / “w” |    |    | – / “y” |    | “h” / – |    |
| Nose (continuant) | – / “m” |    | – / “n” |    |  “ng”  |    |    |

**Naming the sounds** can be done by calling their features. The sound of “b” is called a Voiced Bilabial (meaning “two lips”) Stop. The sound of “f” is known as a Voicelss Labio-dental (meaning “lip-teeth”) Fricative. The sound of “n” is called a Voiced Alveolar (meaning “ridge”) Nasal.

**Symbolizing the sounds** can be done one of two ways. Either you can use the symbol for that sound found in the International Phonetic Alphabet, or you can use well-known symbols from an alphabet known by the reader.

**Consonant Chart** – a consonant symbol chart is offered here without mentioning the Articulators. As you explore the sounds of your language, listening for voicing and feeling the position of your tongue and lips when you make the sound, you can fill out the charts in this article with symbols to represent those sounds.

| Points of Articulation | Lips | Teeth | Ridge | Palate | Velum | Uvula | Glottis |
| -------- | -------- | -------- | -------- | -------- | -------- | -------- | -------- |
| VOICING | -v / +v | -v / +v | -v / +v | -v / +v | -v / +v | -v / +v | -v / +v |
| MANNER |    |    |    |    |    |    |    |
| Stop | “p” / “b” |    | “t” / “d” |    | “k” / “g” |    |    |
| Fricative |    | “f” / “v” | “s” / “z” | “sh” / “zg” |    |    |    |
| Liquid |    |    | – / “l” | – / “r” |    |    |    |
| Semi-vowel) | – / “w” |    |    | – / “y” |    | “h” / – |    |
| Nasals | – / “m” |    | – / “n” |    | “ng” |    |    |
